@@ -31,7 +31,7 @@ ds_diversity <- function(.data, .cols, .name, q = 1) {
     drop_sf() %>%
     dplyr::rowwise() %>%
     dplyr::mutate(.total = sum(dplyr::c_across(!!.cols))) %>%
-    dplyr::mutate(!!.name :=  sum((dplyr::select(dplyr::cur_data(), !!.cols)
+    dplyr::mutate(!!.name :=  sum((dplyr::select(dplyr::across(everything()), !!.cols)
                                                       / .data$.total)^q)^(1 / (1 - q)) ) %>%
     dplyr::pull(!!.name)
 
@@ -47,6 +47,6 @@ ds_diversity <- function(.data, .cols, .name, q = 1) {
 #' @rdname ds_diversity
 #' @param ... arguments to forward to ds_diversity from diversity
 #' @export
-diversity <- function(..., .data = dplyr::cur_data_all()) {
+diversity <- function(..., .data = dplyr::across(everything())) {
   ds_diversity(.data = .data, ...)
 }
